#
# Configuration file for using the gdk-pixbuf library in Xlib applications
#
GDK_PIXBUF_XLIB_LIBDIR="-L/usr/X11R6/lib"
GDK_PIXBUF_XLIB_LIBS="-lgdk_pixbuf_xlib "
GDK_PIXBUF_XLIB_INCLUDEDIR="-I/usr/X11R6/include/gdk-pixbuf-1.0 -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include"
MODULE_VERSION="gdk-pixbuf-0.22.0"
